@@ -13,7 +13,7 @@ package Image::ExifTool::Sanyo;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 my %offOn = (
     0 => 'Off',
@@ -131,7 +131,7 @@ my %offOn = (
         PrintConv => {
             0 => 'Off',
             1 => 'Sport',
-            2 => 'Tv (?)',
+            2 => 'TV',
             3 => 'Night',
             4 => 'User 1',
             5 => 'User 2',
@@ -169,3 +169,39 @@ my %offOn = (
 
 
 1;  # end
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::Sanyo - Definitions for Sanyo EXIF maker notes
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+This module contains definitions required by Image::ExifTool to interpret
+Sanyo maker notes in EXIF information.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 REFERENCES
+
+=over 4
+
+=item http://www.exif.org/makernotes/SanyoMakerNote.html
+
+=back
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
